@@ -1,9 +1,7 @@
 from __future__ import annotations
 
-# Standard library imports.
-from typing import Optional
+from typing import Optional, Any
 
-# Project imports.
 import disruptive.requests as dtrequests
 from disruptive.outputs import OutputBase, Member
 
@@ -49,18 +47,19 @@ class Project(OutputBase):
         OutputBase.__init__(self, project)
 
         # Unpack attributes from dictionary.
-        self.id = project['name'].split('/')[-1]
-        self.display_name = project['displayName']
-        self.organization_id = project['organization'].split('/')[-1]
-        self.organization_display_name = project['organizationDisplayName']
-        self.sensor_count = project['sensorCount']
-        self.cloud_connector_count = project['cloudConnectorCount']
-        self.is_inventory = project['inventory']
+        self.id: str = project['name'].split('/')[-1]
+        self.display_name: str = project['displayName']
+        self.organization_id: str = project['organization'].split('/')[-1]
+        self.organization_display_name: str = \
+            project['organizationDisplayName']
+        self.sensor_count: int = project['sensorCount']
+        self.cloud_connector_count: int = project['cloudConnectorCount']
+        self.is_inventory: bool = project['inventory']
 
     @classmethod
     def get_project(cls,
                     project_id: str,
-                    **kwargs,
+                    **kwargs: Any,
                     ) -> Project:
         """
         Gets the current state of a single project.
@@ -100,7 +99,7 @@ class Project(OutputBase):
     def list_projects(cls,
                       organization_id: Optional[str] = None,
                       query: Optional[str] = None,
-                      **kwargs,
+                      **kwargs: Any,
                       ) -> list[Project]:
         """
         Gets a list of the current state of all available projects.
@@ -152,7 +151,7 @@ class Project(OutputBase):
     def create_project(cls,
                        organization_id: str,
                        display_name: str,
-                       **kwargs,
+                       **kwargs: Any,
                        ) -> Project:
         """
         Create a new project in the specified organization.
@@ -200,7 +199,7 @@ class Project(OutputBase):
     @staticmethod
     def update_project(project_id: str,
                        display_name: Optional[str] = None,
-                       **kwargs,
+                       **kwargs: Any,
                        ) -> None:
         """
         Updates the display name a specified project.
@@ -242,7 +241,7 @@ class Project(OutputBase):
 
     @staticmethod
     def delete_project(project_id: str,
-                       **kwargs,
+                       **kwargs: Any,
                        ) -> None:
         """
         Deletes the specified project.
@@ -283,7 +282,7 @@ class Project(OutputBase):
 
     @staticmethod
     def list_members(project_id: str,
-                     **kwargs,
+                     **kwargs: Any,
                      ) -> list[Member]:
         """
         Gets a list of the current state of all members in a project.
@@ -319,13 +318,14 @@ class Project(OutputBase):
             pagination_key='members',
             **kwargs,
         )
-        return [Member(m) for m in members]
+        members_list: list[Member] = [Member(m) for m in members]
+        return members_list
 
     @staticmethod
     def add_member(project_id: str,
                    email: str,
                    roles: list[str],
-                   **kwargs,
+                   **kwargs: Any,
                    ) -> Member:
         """
         Add a new member to the specified project.
@@ -377,7 +377,7 @@ class Project(OutputBase):
     @staticmethod
     def get_member(member_id: str,
                    project_id: str,
-                   **kwargs,
+                   **kwargs: Any,
                    ) -> Member:
         """
         Get the state of a member in the specified project.
@@ -425,7 +425,7 @@ class Project(OutputBase):
     def update_member(member_id: str,
                       project_id: str,
                       roles: list[str],
-                      **kwargs,
+                      **kwargs: Any,
                       ) -> Member:
         """
         Update the role(s) of the specified member.
@@ -481,7 +481,7 @@ class Project(OutputBase):
     @staticmethod
     def remove_member(member_id: str,
                       project_id: str,
-                      **kwargs,
+                      **kwargs: Any,
                       ) -> None:
         """
         Revoke a member's membership in the specified project.
@@ -523,7 +523,7 @@ class Project(OutputBase):
     @staticmethod
     def get_member_invite_url(member_id: str,
                               project_id: str,
-                              **kwargs,
+                              **kwargs: Any,
                               ) -> str:
         """
         Get the invite URL for a member with pending invite.
@@ -570,14 +570,15 @@ class Project(OutputBase):
         ) + ':getInviteUrl'
 
         # Return url string in GET response.
-        return dtrequests.DTRequest.get(
+        invite_url: str = dtrequests.DTRequest.get(
             url=url,
             **kwargs,
         )['inviteUrl']
+        return invite_url
 
     @staticmethod
     def list_permissions(project_id: str,
-                         **kwargs,
+                         **kwargs: Any,
                          ) -> list[str]:
         """
         List permissions available to the caller in the specified project.
@@ -606,8 +607,9 @@ class Project(OutputBase):
         url = '/projects/{}/permissions'.format(project_id)
 
         # Return list of permissions in GET response.
-        return dtrequests.DTRequest.paginated_get(
+        permissions: list[str] = dtrequests.DTRequest.paginated_get(
             url=url,
             pagination_key='permissions',
             **kwargs,
         )
+        return permissions
